stringutils

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TrimMargin

func TrimMargin(s string) string

TrimMargin takes a string as input and removes whitespace before "|" on each line, similar to Kotlin's TrimMargin function. This makes it easier to format multiline strings in golang code. without having extra whitespace in the actual string.

Types

This section is empty.

Jump to